embassy-stm32

Crates

git

Versions

stm32h7s3z8

Flavors

TransferCompleteMode

Enum TransferCompleteMode 

pub enum TransferCompleteMode {
    EachBlock,
    EachLinkedListItem,
    LastLinkedListItem,
}
Transfer complete event mode (TR2.TCEM).

Controls when the transfer-complete (and half-transfer) events are generated. For linked-list transfers, this is a per-item field loaded from each LLI when UT2 is set.

Variants



EachBlock

Generate TC/HT events at the end of each block transfer.



EachLinkedListItem

Generate TC at the end of each LLI transfer (including loading the next LLI). HT is generated at the half of the LLI data transfer.



LastLinkedListItem

Generate TC only at the end of the last LLI transfer. HT is generated at the half of the last LLI’s data transfer.